
TODO: TODO_16_95_40_30: split help concepts: `help_doc`, `help_hint`, `func_id_help_hint`, ... 

In fact, there are three of them:
*   FS_94_30_49_28 envelope with `help_doc`
*   FS_71_87_33_52 `func_id_help_hint`
*   TODO_16_95_40_30 general `help_hint`

These concepts are used and implemented differently,
but they are explained as related while the only related thing is to show some help which is
already expressed by common prefix "help" in their names.
